Test the spatial heterogeneity in data based on permutation.
spatial_hetero_test_data(
x,
coords,
...,
resample = 5000,
poly = 2,
bw = 10,
kernel = c("bisquared", "gaussian"),
verbose = 0
)A spahetbootres object of permutation-test results with the following items:
varsThe names of variables.
t0The value of the statistics on original values.
tThe value of the same statistics on permuted values.
pThe p-value for each variable.
Currently, variance is used as the statistics.
A matrix of data to be tested. Each column is a variable.
A matrix of coordinates.
Additional arguments.
The total times of resampling with replacement. Default to 5000.
The number of polynomial terms used by the polynomial estimator. Default to 2.
The adaptive bandwidth used by the polynomial estimator. Default to 10.
The kernel function used by the polynomial estimator.
The verbosity level. Default to 0.